"""Core capybara modules.

Please import directly from submodules:
- capybara.core.agent
- capybara.core.execution
- capybara.core.delegation
- capybara.core.config
- capybara.core.utils
- capybara.core.logging
"""
